import { BasicColumn, FormSchema } from '@/components/Table';
import { DescItem } from '@/components/Description';
import { style } from '@logicflow/extension/es/bpmn-elements/presets/icons';
import { h, VNodeChild } from 'vue';

export const columns: BasicColumn[] = [
  {
    title: '数据集名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '描述',
    dataIndex: 'remark',
    width: 150,
  },
  {
    title: '来源',
    dataIndex: 'source',
    width: 120,
  },
  {
    title: '权属机构',
    dataIndex: 'workgroup',
    width: 120,
  },
  {
    title: '创建时间',
    dataIndex: 'createTime',
    width: 150,
  },
  {
    title: '版本发布状态',
    dataIndex: 'status',
    width: 150,
  },
  {
    title: '上架状态',
    dataIndex: 'uploadStatus',
    width: 100,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: ' ',
    component: 'Input',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '搜索文件名称',
    },
  },
  {
    field: 'workGroup',
    label: ' ',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '权属机构',
      options: [
        { label: '测试功能部', value: '11' },
        { label: '开发部', value: '12' },
        { label: '市场部', value: '13' },
        { label: '财务部', value: '14' },
      ],
    },
  },
  {
    field: 'status',
    label: ' ',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '版本发布状态',
      options: [
        { label: '已发布', value: '0' },
        { label: '未发布', value: '1' },
      ],
    },
  },
  {
    field: 'uploadStatus',
    label: ' ',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '上架状态',
      options: [
        { label: '已上架', value: '0' },
        { label: '未上架', value: '1' },
      ],
    },
  },
  {
    field: 'source',
    label: ' ',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '来源',
      options: [
        { label: 'Hive', value: 'Hive' },
        { label: 'Hbase', value: 'Hbase' },
        { label: 'Kafka', value: 'Kafka' },
      ],
    },
  },
];
export const MoveFormSchema: any[] = [
  {
    field: 'taskId',
    label: '路径',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      // border: 'none',
      fieldNames: {
        label: 'workSpaceName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
];
export const formSchemaNewFolder: any = [
  {
    field: 'path',
    label: '路径',
    component: 'TreeSelect',
    rules: [
      {
        required: true,
        message: '请选择上级菜单',
      },
    ],
    componentProps: {
      fieldNames: {
        label: 'workSpaceName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
  },

  {
    field: 'name',
    label: '文件夹名称',
    component: 'Input',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入文件夹名称',
    },
  },
];
export const addFileFormSchema: any = [
  {
    field: 'path',
    label: '数据集路径',
    component: 'TreeSelect',
    rules: [
      {
        required: true,
        message: '请选择上级菜单',
      },
    ],
    componentProps: {
      fieldNames: {
        label: 'workSpaceName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'name',
    label: '数据集名称',
    component: 'Input',
    componentProps: {
      placeholder: '输入文件名称',
    },
    colProps: { lg: 24, md: 24 },
  },
];
export const editFileFormSchema: any = [
  {
    field: 'name',
    label: '资源名称',
    component: 'Input',
    required: true,
    colProps: { lg: 10, md: 10 },
  },
  {
    field: 'path',
    label: '路径',
    component: 'TreeSelect',
    componentProps: {
      fieldNames: {
        label: 'workSpaceName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    colProps: { lg: 10, md: 10 },
  },
  {
    field: 'remark',
    label: '描述',
    component: 'Input',
    colProps: { lg: 10, md: 10 },
  },
  {
    field: 'workGroup',
    label: '权属机构',
    component: 'TreeSelect',
    componentProps: {
      placeholder: '请选择权属机构',
      treeData: [
        {
          title: '部门',
          businessId: '1',
          parentId: '0',
          children: [
            {
              title: '测试功能部',
              businessId: '11',
              parentId: '1',
            },
            {
              title: '开发部',
              businessId: '12',
              parentId: '1',
            },
            {
              title: '市场部',
              businessId: '13',
              parentId: '1',
            },
            {
              title: '财务部',
              businessId: '14',
              parentId: '1',
            },
          ],
        },
      ],
      fieldNames: {
        label: 'title',
        value: 'businessId',
      },
    },
    colProps: { lg: 10, md: 10 },
  },
  {
    field: 'tag',
    label: '业务标签',
    component: 'Select',
    componentProps: {
      placeholder: '请选择业务标签',
      options: [
        { label: '测试', value: '测试' },
        { label: '开发', value: '开发' },
        { label: '市场', value: '市场' },
        { label: '财务', value: '财务' },
      ],
    },
    colProps: { lg: 10, md: 10 },
  },
  {
    field: 'source',
    label: '来源',
    component: 'Input',
    componentProps: {
      disabled: true,
    },
    defaultValue: '元数据',
    colProps: { lg: 10, md: 10 },
  },
];
export const editFilePermissionsFormSchema: any = [
  {
    field: 'download',
    label: '下载权限',
    component: 'Switch',
    required: true,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'encrypt',
    label: '文件加密',
    component: 'Switch',
    required: true,
    ifShow: ({ model }) => model.download === true,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'push',
    label: '推送权限',
    component: 'Switch',
    required: true,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'hdfs',
    label: 'HDFS数据源',
    component: 'Select',
    componentProps: {
      placeholder: '请选择HDFS数据源',
      options: [
        { label: 'Hive', value: 'Hive' },
        { label: 'Hbase', value: 'Hbase' },
        { label: 'Kafka', value: 'Kafka' },
      ],
    },
    required: true,
    colProps: { lg: 24, md: 24 },
    ifShow: ({ model }) => model.push === true,
  },
  {
    field: 'pushType',
    label: '推送类型',
    component: 'RadioGroup',
    defaultValue: '1',
    componentProps: {
      options: [
        { label: '增量', value: '1' },
        { label: '全量', value: '2' },
      ],
    },
    ifShow: ({ model }) => model.push === true,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'schedulePush',
    label: '定时推送',
    component: 'Switch',
    required: true,
    ifShow: ({ model }) => model.push === true,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'api',
    label: 'API调用',
    component: 'Switch',
    required: true,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'filterType',
    label: '数据过滤方式',
    component: 'CheckboxGroup',
    componentProps: {
      options: [
        { label: '自定义条件', value: '1' },
        { label: '按机构过滤', value: '2' },
        { label: '按时间过滤', value: '3' },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'filterAlter',
    label: ' ',
    slot: 'filterAlter',
    colProps: { lg: 24, md: 24 },
  },
];
export const editFileOptionsFormSchema: any = [
  {
    field: 'autoOffShelfDate',
    label: '自动下架日期',
    component: 'Input',
    required: true,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'shareType',
    label: '共享方式',
    component: 'Select',
    componentProps: {
      placeholder: '请选择共享方式',
      options: [
        { label: '公开', value: '公开' },
        { label: '私有', value: '私有' },
      ],
    },
    required: true,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'visibleRange',
    label: '可见范围',
    component: 'Select',
    componentProps: {
      placeholder: '请选择可见范围',
      options: [
        { label: '公开', value: '公开' },
        { label: '私有', value: '私有' },
      ],
    },
    required: true,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'filterCondition',
    label: '数据过滤条件',
    component: 'Input',
    required: true,
    colProps: { lg: 24, md: 24 },
  },
];
export const editSourceTableFormSchema: any = [
  {
    field: 'source',
    label: '数据源',
    component: 'Select',
    defaultValue: 'Hive',
    componentProps: {
      placeholder: '请选择数据源',
      options: [{ label: 'Hive', value: 'Hive' }],
      disabled: true,
    },
    required: true,
    colProps: { lg: 10, md: 10 },
  },
  {
    field: 'database',
    label: '数据库',
    component: 'Select',
    defaultValue: 'default',
    componentProps: {
      placeholder: '请选择数据源',
      options: [{ label: 'default', value: 'default' }],
      disabled: true,
    },
    required: true,
    colProps: { lg: 10, md: 10 },
  },
  {
    field: 'table',
    label: '数据源表',
    component: 'Input',
    defaultValue: 'blood_table',
    componentProps: {
      disabled: true,
    },
    required: true,
    colProps: { lg: 10, md: 10 },
  },
  {
    field: 'size',
    label: '大小',
    component: 'Input',
    defaultValue: '1.8KB',
    componentProps: {
      disabled: true,
    },
    required: true,
    colProps: { lg: 10, md: 10 },
  },
];
export const editColumns: BasicColumn[] = [
  {
    title: '字段',
    dataIndex: 'field',
    width: 120,
  },
  {
    title: '中文名',
    dataIndex: 'name',
    width: 150,
  },
  {
    title: '字段描述',
    dataIndex: 'remark',
    width: 120,
  },
  {
    title: '字段类型',
    dataIndex: 'type',
    width: 120,
  },
  {
    title: '安全分级',
    dataIndex: 'security',
    width: 150,
  },
  {
    title: '敏感状态',
    dataIndex: 'status',
    width: 150,
  },
  {
    title: '敏感类型',
    dataIndex: 'sensitiveType',
    width: 100,
  },
];
export const searchEditFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: ' ',
    component: 'Input',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '搜索名称',
    },
  },
];
export const basicSchema: DescItem[] = [
  {
    field: 'name',
    label: '资源名称',
  },
  {
    field: 'description',
    label: '描述',
  },
  {
    field: 'tags',
    label: '业务标签',
  },
  {
    field: 'owner',
    label: '权属机构',
  },
  {
    field: 'sensitiveStatus',
    label: '敏感状态',
  },
  {
    field: 'version',
    label: '版本',
  },
  {
    field: 'source',
    label: '来源',
  },
];
export const sourceTableSchema: DescItem[] = [
  {
    field: 'name',
    label: '表名',
  },
  {
    field: 'path',
    label: '路径',
  },
  {
    field: 'size',
    label: '大小',
  },
  {
    field: 'filterCondition',
    label: '数据过滤条件',
  },
];
export const optionSchema: DescItem[] = [
  {
    field: 'autoOffShelfDate',
    label: '自动下架日期',
  },
  {
    field: 'shareType',
    label: '共享方式',
  },
  {
    field: 'visibleRange',
    label: '可见范围',
  },
  {
    field: 'filterCondition',
    label: '数据过滤条件',
  },
];
export const permissionSchema: DescItem[] = [
  {
    field: 'download',
    label: '下载权限',
  },
  {
    field: 'encryption',
    label: '文件加密',
  },
  {
    field: 'push',
    label: '推送权限',
  },
  {
    field: 'api',
    label: 'API调用',
  },
  {
    field: 'filterType',
    label: '数据过滤方式',
  },
];
export const informationColumns: BasicColumn[] = [
  {
    title: '字段',
    dataIndex: 'field',
    width: 120,
  },
  {
    title: '中文名',
    dataIndex: 'name',
    width: 150,
  },
  {
    title: '字段描述',
    dataIndex: 'remark',
    width: 150,
  },
  {
    title: '字段类型',
    dataIndex: 'type',
    width: 120,
  },
  {
    title: '安全分级',
    dataIndex: 'security',
    width: 120,
  },
  {
    title: '敏感状态',
    dataIndex: 'status',
    width: 150,
  },
  {
    title: '敏感类型',
    dataIndex: 'sensitiveType',
    width: 100,
  },
  {
    title: '数据标准',
    dataIndex: 'standard',
    width: 100,
  },
];
function renderHeader(column: BasicColumn, isSensitive: boolean): VNodeChild {
  const style = isSensitive ? { color: 'orange' } : {};
  return h('span', { style }, column.title);
}
export const sampleDataColumns: BasicColumn[] = [
  {
    title: 'name(敏感)',
    dataIndex: 'name',
    customHeaderRender: (column) => renderHeader(column, true),
    width: 120,
  },
  {
    title: 'phone_number_string(敏感)',
    dataIndex: 'phone_number_string',
    customHeaderRender: (column) => renderHeader(column, true),
    width: 150,
  },
  {
    title: 'student_id(敏感)',
    dataIndex: 'student_id',
    customHeaderRender: (column) => renderHeader(column, true),
    width: 150,
  },
  {
    title: 'major(敏感)',
    dataIndex: 'major',
    customHeaderRender: (column) => renderHeader(column, true),
    width: 120,
  },
  {
    title: 'origin_city',
    dataIndex: 'origin_city',
    width: 120,
  },
  {
    title: 'ethnic(敏感)',
    dataIndex: 'ethnic',
    customHeaderRender: (column) => renderHeader(column, true),
    width: 150,
  },
  {
    title: 'building_num',
    dataIndex: 'building_num',
    width: 100,
  },
];
export const globalDataColumns: BasicColumn[] = [
  {
    title: '公共资源名称',
    dataIndex: 'name',
    width: 100,
  },
  {
    title: '上架状态',
    dataIndex: 'status',
    width: 100,
  },
];
export const uploadFieldColumns: BasicColumn[] = [
  {
    title: '列名',
    dataIndex: 'name',
    width: 100,
  },
  {
    title: '中文名',
    dataIndex: 'chineseName',
    width: 100,
  },
  {
    title: '数据类型',
    dataIndex: 'type',
    width: 100,
  },
];
export const versionPublishSchema: FormSchema[] = [
  {
    field: 'title',
    label: '申请标题',
    component: 'Input',
    defaultValue: '申请发布V10.0版本：数据集1',
    required: true,
  },
  {
    field: 'reason',
    label: '申请理由',
    component: 'Input',
  },
  {
    field: 'remark',
    label: '版本说明',
    component: 'Input',
    required: true,
  },
  {
    field: 'scope',
    label: '生效范围',
    component: 'Select',
    defaultValue: '1',
    componentProps: {
      options: [
        {
          label: '存量任务和新增任务',
          value: '1',
        },
        {
          label: '全部',
          value: '2',
        },
      ],
    },
    required: true,
  },
];
